@@ -68,7 +68,7 @@ done
 find "$mozjspath" -type d -empty -delete
 
 tmpout=$(mktemp /tmp/mozjs-debimport-XXXXXXXXX.diff)
-echo "Differencies found with orig saved at $tmpout, consider adjusting filters"
+echo "Differences found with orig saved at $tmpout, consider adjusting filters"
 diff -rq "$srcpath" "$mozjspath" > "$tmpout" || true
 
 rm -rf "$srcpath"
